@@ -1,5 +1,5 @@
 import click
-from app.aitest_application import configure,run,status
+from app import application
 
 
 @click.group()
